@@ -1,6 +1,6 @@
 package Bar;
 our VERSION='1.234567';
-no 5.999.999;
+no v5.999999;
 1
 __END__
 
